==> 0.0.5.tar.gz: lib/stream_binder.dart <==
library stream_binder;

import "dart:async";
import "dart:convert";

typedef void Send(String str);
typedef void OnDone();
class Binder{
  
  CompositionMapper<Operator> _operators = new CompositionMapper();
  Send _send;
  OnDone _on_done;
  
  
  Binder(Stream<String> listen,this._send){
    var _json_parse = new StreamTransformer<String,String>.fromHandlers(handleData:_toMessage);
    listen.transform(_json_parse).listen(_send,onDone: _onDone);
    
  }
  
  void _onDone(){
    if(_on_done!= null){
      _on_done();
    }
  }
  
  int _addOperation(Operator operator){
    return _operators.add(operator);
    
  }
  
  void _toMessage(String str,EventSink<String> e){
    var msg = new Message(JSON.decode(str));
    var operator = _operators._composition_map[msg.operation_id];
    
    if(msg.isRequest){
      if(operator._tr != null){
        operator._tr(msg.body,(l) => e.add(JSON.encode([false,msg.operation_id,msg.request_id,l])));
      }
      return;
    }
    
    operator._onResponse(msg);
    
  }
  
  SendRequest _getSendRequest(Operator o){
    var i = _operators.getId(o);
    return (int req_id , List req_data) => _send(JSON.encode([true,i,req_id,req_data]));
  }
  
}

class Message{
  List data;
  Message(this.data);
  
  bool get isRequest => data[0];
  int get operation_id => data[1];
  int get request_id => data[2];
  List get body => data[3];
  
}

typedef void ToResponse(List req_data,void res(List res_data));
typedef void SendRequest(int request_id, List request_data);

class Operator{
  
  int _operator_id;  
  ToResponse _tr;
  CompositionMapper<Completer>_requests = new CompositionMapper();
  SendRequest _send_request;
  
  Operator(Binder binder){
    binder._addOperation(this);
    _send_request = binder._getSendRequest(this);
  }
  
  void onRequest(ToResponse tr){
    _tr = tr;
  }
  
  Future<List> request(List send_data){
    var completer = new Completer();
    var id = _requests.add(completer);
    _send_request(id,send_data);
    return completer.future;
  }
  
  void _onResponse(Message message){
    _requests._composition_map[message.request_id].complete(message.body);
  }
  
}


class CompositionMapper<E>{
  Map<int,E> _composition_map = {};
  int _max = 0;
  
  int add(E e){
    var i = _max ++;
    _composition_map[i] = e;
    return i;
  }
  
  int getId(E e){
    for(var i in _composition_map.keys){
      if(_composition_map[i] == e){
        return i;
      }
    }
    throw "未登録";
  }
  
}

==> 0.0.7.tar.gz: lib/stream_binder.dart <==
library stream_binder;

import "dart:async";
import "dart:convert";

typedef void Send(String str);
class Binder{
  
  CompositionMapper<Operator> _operators = new CompositionMapper();
  Send _send;
  Operator onDone;
  
  
  Binder(Stream<String> listen,this._send){
    var _json_parse = new StreamTransformer<String,String>.fromHandlers(handleData:_toMessage);
    onDone = new Operator(this);
    listen.transform(_json_parse).listen(_send,onDone:()=> onDone.request([]));
    
  }

  
  int _addOperation(Operator operator){
    return _operators.add(operator);
    
  }
  
  void _toMessage(String str,EventSink<String> e){
    var msg = new Message(JSON.decode(str));
    var operator = _operators._composition_map[msg.operation_id];
    
    if(msg.isRequest){
      if(operator._tr != null){
        operator._tr(msg.body,(l) => e.add(JSON.encode([false,msg.operation_id,msg.request_id,l])));
      }
      return;
    }
    
    operator._onResponse(msg);
    
  }
  
  SendRequest _getSendRequest(Operator o){
    var i = _operators.getId(o);
    return (int req_id , List req_data) => _send(JSON.encode([true,i,req_id,req_data]));
  }
  
}

class Message{
  List data;
  Message(this.data);
  
  bool get isRequest => data[0];
  int get operation_id => data[1];
  int get request_id => data[2];
  List get body => data[3];
  
}

typedef void ToResponse(List req_data,void res(List res_data));
typedef void SendRequest(int request_id, List request_data);

class Operator{
  
  int _operator_id;  
  ToResponse _tr;
  CompositionMapper<Completer>_requests = new CompositionMapper();
  SendRequest _send_request;
  
  Operator(Binder binder){
    binder._addOperation(this);
    _send_request = binder._getSendRequest(this);
  }
  
  void onRequest(ToResponse tr){
    _tr = tr;
  }
  
  Future<List> request(List send_data){
    var completer = new Completer();
    var id = _requests.add(completer);
    _send_request(id,send_data);
    return completer.future;
  }
  
  void _onResponse(Message message){
    _requests._composition_map[message.request_id].complete(message.body);
  }
  
}


class CompositionMapper<E>{
  Map<int,E> _composition_map = {};
  int _max = 0;
  
  int add(E e){
    var i = _max ++;
    _composition_map[i] = e;
    return i;
  }
  
  int getId(E e){
    for(var i in _composition_map.keys){
      if(_composition_map[i] == e){
        return i;
      }
    }
    throw "未登録";
  }
  
}
